@@ -2,6 +2,7 @@ package openai_compatible
 
 import (
 	"context"
+	"fmt"
 	"os"
 	"strings"
 
@@ -38,8 +39,12 @@ func NewClient(providerConfig ProviderConfig) *Client {
 
 // ListModels overrides the default ListModels to handle different response formats
 func (c *Client) ListModels() ([]string, error) {
-	// If a custom models URL is provided, use direct fetch with that URL
+	// If a custom models URL is provided, handle it
 	if c.modelsURL != "" {
+		// Check for static model list
+		if strings.HasPrefix(c.modelsURL, "static:") {
+			return c.getStaticModels(c.modelsURL)
+		}
 		// TODO: Handle context properly in Fabric by accepting and propagating a context.Context
 		// instead of creating a new one here.
 		return openai.FetchModelsDirectly(context.Background(), c.modelsURL, c.Client.ApiKey.Value, c.GetName())
@@ -55,6 +60,68 @@ func (c *Client) ListModels() ([]string, error) {
 	return c.DirectlyGetModels(context.Background())
 }
 
+// getStaticModels returns a predefined list of models for providers that don't support model discovery
+func (c *Client) getStaticModels(modelsKey string) ([]string, error) {
+	switch modelsKey {
+	case "static:abacus":
+		return []string{
+			"route-llm",
+			"gpt-4o-2024-11-20",
+			"gpt-4o-mini",
+			"o4-mini",
+			"o3-pro",
+			"o3",
+			"o3-mini",
+			"gpt-4.1",
+			"gpt-4.1-mini",
+			"gpt-4.1-nano",
+			"gpt-5",
+			"gpt-5-mini",
+			"gpt-5-nano",
+			"gpt-5.1",
+			"gpt-5.1-chat-latest",
+			"openai/gpt-oss-120b",
+			"claude-3-7-sonnet-20250219",
+			"claude-sonnet-4-20250514",
+			"claude-opus-4-20250514",
+			"claude-opus-4-1-20250805",
+			"claude-sonnet-4-5-20250929",
+			"claude-haiku-4-5-20251001",
+			"claude-opus-4-5-20251101",
+			"meta-llama/Llama-4-Maverick-17B-128E-Instruct-FP8",
+			"meta-llama/Meta-Llama-3.1-405B-Instruct-Turbo",
+			"meta-llama/Meta-Llama-3.1-70B-Instruct",
+			"meta-llama/Meta-Llama-3.1-8B-Instruct",
+			"llama-3.3-70b-versatile",
+			"gemini-2.0-flash-001",
+			"gemini-2.0-pro-exp-02-05",
+			"gemini-2.5-pro",
+			"gemini-2.5-flash",
+			"gemini-3-pro-preview",
+			"qwen-2.5-coder-32b",
+			"Qwen/Qwen2.5-72B-Instruct",
+			"Qwen/QwQ-32B",
+			"Qwen/Qwen3-235B-A22B-Instruct-2507",
+			"Qwen/Qwen3-32B",
+			"qwen/qwen3-coder-480b-a35b-instruct",
+			"qwen/qwen3-Max",
+			"grok-4-0709",
+			"grok-4-fast-non-reasoning",
+			"grok-4-1-fast-non-reasoning",
+			"grok-code-fast-1",
+			"kimi-k2-turbo-preview",
+			"deepseek/deepseek-v3.1",
+			"deepseek-ai/DeepSeek-V3.1-Terminus",
+			"deepseek-ai/DeepSeek-R1",
+			"deepseek-ai/DeepSeek-V3.2",
+			"zai-org/glm-4.5",
+			"zai-org/glm-4.6",
+		}, nil
+	default:
+		return nil, fmt.Errorf("unknown static model list: %s", modelsKey)
+	}
+}
+
 // ProviderMap is a map of provider name to ProviderConfig for O(1) lookup
 var ProviderMap = map[string]ProviderConfig{
 	"AIML": {
@@ -128,6 +195,12 @@ var ProviderMap = map[string]ProviderConfig{
 		BaseURL:             "https://api.z.ai/api/paas/v4",
 		ImplementsResponses: false,
 	},
+	"Abacus": {
+		Name:                "Abacus",
+		BaseURL:             "https://routellm.abacus.ai/v1/",
+		ModelsURL:           "static:abacus", // Special marker for static model list
+		ImplementsResponses: false,
+	},
 }
 
 // GetProviderByName returns the provider configuration for a given name with O(1) lookup
