@@ -25,6 +25,11 @@ func TestCreateClient(t *testing.T) {
 			provider: "Z AI",
 			exists:   true,
 		},
+		{
+			name:     "Existing provider - Abacus",
+			provider: "Abacus",
+			exists:   true,
+		},
 		{
 			name:     "Non-existent provider",
 			provider: "NonExistent",
